@@ -2,7 +2,7 @@ import ast
 import re
 from ast import expr
 
-from sympy import Add, Mul, Pow, Eq
+from sympy import Add, Mul, Pow, Eq, Not, Xor
 
 from expr_codegen.expr import register_symbols, dict_to_exprs
 
@@ -125,6 +125,7 @@ class RenameTransformer(ast.NodeTransformer):
     def __init__(self, funcs_map, targets_map, args_map=None):
 
         if args_map is None:
+            # 保留字
             args_map = {'True': "_TRUE_", 'False': "_FALSE_", 'None': "_NONE_"}
         self.funcs_old = set()
         self.args_old = set()
@@ -372,6 +373,8 @@ def _add_default_type(globals_):
     globals_['Mul'] = Mul
     globals_['Pow'] = Pow
     globals_['Eq'] = Eq
+    globals_['Not'] = Not
+    globals_['Xor'] = Xor
     return globals_
 
 
